class Modal {
    constructor(formData = {}, button1 = null, button2 = null, confirmForm = "Your booking is confirmed") {
        this.isOpen = false;
        this.formData = formData;
        this.button1Name = button1;
        this.button2Name = button2;
        this.confirmForm = confirmForm;
        this.heading = formData.heading || "Modal Title";

        this.loadStyles();
        this.init();
    }

    loadStyles() {
        const link = document.createElement("link");
        link.rel = "stylesheet";
        link.href = "https://cdn.jsdelivr.net/npm/button-popup-modal/modal.css"; // CDN fallback
        document.head.appendChild(link);
    }

    init() {
        this.createButton();
        this.createModal();
        this.createConfirmModal();
    }

    createButton() {
        this.button = document.createElement("button");
        this.button.innerText = "Open Modal";
        this.button.className = "open-modal-button";
        this.button.addEventListener("click", () => this.openModal());
        document.body.appendChild(this.button);
    }

    createModal() {
        this.modalOverlay = document.createElement("div");
        this.modalOverlay.className = "modal-overlay hidden";
        this.modalOverlay.addEventListener("click", (event) => {
            if (event.target === this.modalOverlay) {
                this.closeModal();
            }
        });

        this.modal = document.createElement("div");
        this.modal.className = "modal";
        this.modal.setAttribute("role", "dialog");
        this.modal.setAttribute("aria-labelledby", "modal-heading");
        this.modal.setAttribute("aria-modal", "true");

        this.closeButton = document.createElement("button");
        this.closeButton.innerHTML = "&times;";
        this.closeButton.className = "close-button";
        this.closeButton.setAttribute("aria-label", "Close modal");
        this.closeButton.addEventListener("click", () => this.closeModal());

        this.modalHeading = document.createElement("h2");
        this.modalHeading.className = "modal-heading";
        this.modalHeading.id = "modal-heading";
        this.modalHeading.innerText = this.heading;
        this.modalHeading.style.textAlign = "center";

        this.content = document.createElement("div");
        this.content.className = "modal-content";

        if (this.formData) {
            this.generateLabels(this.formData);
        }

        this.modalActions = document.createElement("div");
        this.modalActions.className = "modal-actions";

        if (this.button1Name) {
            this.button1 = document.createElement("button");
            this.button1.innerText = this.button1Name;
            this.button1.className = "cancel-action-button action-button";
            this.button1.addEventListener("click", () => this.closeModal());
            this.modalActions.appendChild(this.button1);
        }

        if (this.button2Name) {
            this.button2 = document.createElement("button");
            this.button2.innerText = this.button2Name;
            this.button2.className = "book-action-button action-button";
            this.button2.addEventListener("click", () => {
                this.closeModal();
                setTimeout(() => this.openConfirmModal(), 300);
            });
            this.modalActions.appendChild(this.button2);
        }

        this.modal.appendChild(this.closeButton);
        this.modal.appendChild(this.modalHeading);
        this.modal.appendChild(this.content);
        this.modal.appendChild(this.modalActions);

        this.modalOverlay.appendChild(this.modal);
        document.body.appendChild(this.modalOverlay);
    }

    createConfirmModal() {
        this.confirmOverlay = document.createElement("div");
        this.confirmOverlay.className = "modal-overlay hidden";
        
        this.confirmModal = document.createElement("div");
        this.confirmModal.className = "modal confirm-modal";
        this.confirmModal.setAttribute("role", "alertdialog");
        this.confirmModal.setAttribute("aria-labelledby", "confirm-heading");
        this.confirmModal.setAttribute("aria-modal", "true");
        
        this.confirmHeading = document.createElement("h2");
        this.confirmHeading.className = "modal-heading";
        this.confirmHeading.id = "confirm-heading";
        this.confirmHeading.innerText = "Confirmation";
        this.confirmHeading.style.textAlign = "center";
        
        this.confirmMessageElem = document.createElement("p");
        this.confirmMessageElem.className = "modal-confirm-message";
        this.confirmMessageElem.innerText = this.confirmForm;
        
        this.confirmCloseButton = document.createElement("button");
        this.confirmCloseButton.innerText = "Close";
        this.confirmCloseButton.className = "confirm-close-button action-button";
        this.confirmCloseButton.addEventListener("click", () => this.closeConfirmModal());
        
        this.confirmModal.appendChild(this.confirmHeading);
        this.confirmModal.appendChild(this.confirmMessageElem);
        this.confirmModal.appendChild(this.confirmCloseButton);
        
        this.confirmOverlay.appendChild(this.confirmModal);
        document.body.appendChild(this.confirmOverlay);
    }

    generateLabels(formData) {
        this.content.innerHTML = "";
        for (const [key, value] of Object.entries(formData)) {
            if (key === "heading") continue;

            const labelContainer = document.createElement("div");
            labelContainer.className = "modal-label-container";

            const label = document.createElement("label");
            label.className = "modal-label";
            label.innerHTML = `<strong>${key}:</strong>`;

            const valueSpan = document.createElement("span");
            valueSpan.className = "modal-value";
            valueSpan.innerText = value;

            labelContainer.appendChild(label);
            labelContainer.appendChild(valueSpan);
            this.content.appendChild(labelContainer);
        }
    }

    openModal() {
        this.modalOverlay.classList.remove("hidden");
    }

    closeModal() {
        this.modalOverlay.classList.add("hidden");
    }

    openConfirmModal() {
        this.closeModal();
        this.confirmOverlay.classList.remove("hidden");
    }

    closeConfirmModal() {
        this.confirmOverlay.classList.add("hidden");
    }
}

export default Modal;

if (typeof window !== "undefined") {
    window.ButtonPopupModal = Modal;
}
